package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableLongPredicate.class */
public interface FailableLongPredicate<E extends Throwable> {
    public static final FailableLongPredicate FALSE = t -> {
        return false;
    };
    public static final FailableLongPredicate TRUE = t -> {
        return true;
    };

    boolean test(long j) throws Throwable;

    static <E extends Throwable> FailableLongPredicate<E> falsePredicate() {
        return FALSE;
    }

    static <E extends Throwable> FailableLongPredicate<E> truePredicate() {
        return TRUE;
    }

    default FailableLongPredicate<E> and(FailableLongPredicate<E> other) {
        Objects.requireNonNull(other);
        return t -> {
            return test(t) && other.test(t);
        };
    }

    default FailableLongPredicate<E> negate() {
        return t -> {
            return !test(t);
        };
    }

    default FailableLongPredicate<E> or(FailableLongPredicate<E> other) {
        Objects.requireNonNull(other);
        return t -> {
            return test(t) || other.test(t);
        };
    }
}
